==> HiCShuffle-1.0.2.tar.gz: HiCShuffle-1.0.2/README.md <==
# HiCShuffle

[![PyPI version](https://badge.fury.io/py/HiCShuffle.svg)](https://badge.fury.io/py/HiCShuffle)
[![DOI:10.1101/2021.09.23.459925](https://zenodo.org/badge/DOI/10.1101/2021.09.23.459925.svg)](https://doi.org/10.1101/2021.09.23.459925)
[![MIT license](https://img.shields.io/badge/License-MIT-blue.svg)](https://lbesson.mit-license.org/)
[![Linux](https://svgshare.com/i/Zhy.svg)](https://svgshare.com/i/Zhy.svg)

**FASTQ Shuffling Tool For Sanity Check in Hi-C Differential Contact Analysis**

## Installation
```shell
pip install hicshuffle
```

## Usage

### hicshuffle <command> [options]

```shell
Commands:
    diff            FASTQ Shuffling Tool For Sanity Check in Hi-C Differential Contact Analysis
Run panchip <command> -h for help on a specific command.

HiCShuffle: FASTQ Shuffling Tool For Sanity Check in Hi-C Differential Contact Analysis

positional arguments:
  command     Subcommand to run

optional arguments:
  -h, --help  show this help message and exit
  --version   show program's version number and exit
```

### hicshuffle diff [-h] query_path_1 query_path_2 reference_path_1 reference_path_2 output_directory

```shell

FASTQ Shuffling Tool For Sanity Check in Hi-C Differential Contact Analysis

positional arguments:
  query_path_1      Path for READ1 of Query FASTQ
  query_path_2      Path for READ2 of Query FASTQ
  reference_path_1  Path for READ1 of Reference FASTQ
  reference_path_2  Path for READ2 of Reference FASTQ
  output_directory  Output Directory... HiCShuffle Will Generate Output Directory If Not Existent

optional arguments:
  -h, --help         show this help message and exit
```

==> HiCShuffle-1.0.8.tar.gz: HiCShuffle-1.0.8/README.md <==
# HiCShuffle

[![PyPI version](https://badge.fury.io/py/HiCShuffle.svg)](https://badge.fury.io/py/HiCShuffle)
[![DOI:10.1101/2021.09.23.459925](https://zenodo.org/badge/DOI/10.1101/2021.09.23.459925.svg)](https://doi.org/10.1101/2021.09.23.459925)
[![MIT license](https://img.shields.io/badge/License-MIT-blue.svg)](https://lbesson.mit-license.org/)
[![Linux](https://svgshare.com/i/Zhy.svg)](https://svgshare.com/i/Zhy.svg)

**FASTQ Shuffling Tool For Sanity Check in Hi-C Differential Contact Analysis**

## Installation
```shell
pip install hicshuffle
```

## Usage

### hicshuffle <command> [options]

```shell
Commands:
    diff            FASTQ Shuffling Tool For Sanity Check in Hi-C Differential Contact Analysis
Run panchip <command> -h for help on a specific command.

HiCShuffle: FASTQ Shuffling Tool For Sanity Check in Hi-C Differential Contact Analysis

positional arguments:
  command     Subcommand to run

optional arguments:
  -h, --help  show this help message and exit
  --version   show program's version number and exit
```

### hicshuffle diff [-h] query_path_1 query_path_2 reference_path_1 reference_path_2 output_directory

```shell

FASTQ Shuffling Tool For Sanity Check in Hi-C Differential Contact Analysis

positional arguments:
  query_path_1      Path for READ1 of GZ-Compressed or Uncompressed Query FASTQ
  query_path_2      Path for READ2 of GZ-Compressed or Uncompressed Query FASTQ
  reference_path_1  Path for READ1 of GZ-Compressed or Uncompressed Reference FASTQ
  reference_path_2  Path for READ2 of GZ-Compressed or Uncompressed Reference FASTQ
  output_directory  Output Directory... HiCShuffle Will Generate Output Directory If Not Existent

optional arguments:
  -h, --help         show this help message and exit
```
